@@ -2,6 +2,9 @@
 #ifndef _CRT_SECURE_NO_WARNINGS
 #define _CRT_SECURE_NO_WARNINGS 1
 #endif
+#ifndef _CRT_NONSTDC_NO_WARNINGS
+#define _CRT_NONSTDC_NO_WARNINGS 1
+#endif
 #endif
 
 #include <stdio.h>
@@ -19,8 +22,13 @@
 #endif
 
 #ifdef _WIN32
+#include <io.h>
+#include <fcntl.h>
 #include <windows.h>
 
+#define isatty(h) _isatty(h)
+#define fileno(m) _fileno(m)
+
 int get_argv_utf8(int* argc_ptr, char*** argv_ptr) {
   int argc;
   char** argv;
@@ -40,6 +48,8 @@ int get_argv_utf8(int* argc_ptr, char*** argv_ptr) {
   *argv_ptr = argv;
   return 0;
 }
+#else
+#include <unistd.h>
 #endif
 
 int output(int error_status, const char* error_message, const char* output_string, const char* outfile) {
@@ -52,7 +62,7 @@ int output(int error_status, const char* error_message, const char* output_strin
         return 1;
     } else if (output_string) {
         if(outfile) {
-            FILE* fp = fopen(outfile, "w");
+            FILE* fp = fopen(outfile, "wb");
             if(!fp) {
                 perror("Error opening output file");
                 return 1;
@@ -65,6 +75,9 @@ int output(int error_status, const char* error_message, const char* output_strin
             fclose(fp);
         }
         else {
+            #ifdef _WIN32
+              setmode(fileno(stdout), O_BINARY);
+            #endif
             printf("%s", output_string);
         }
         return 0;
@@ -206,6 +219,11 @@ int main(int argc, char** argv) {
 #ifdef _WIN32
     get_argv_utf8(&argc, &argv);
 #endif
+    if ((argc == 1) && isatty(fileno(stdin))) {
+        print_usage(argv[0]);
+        return 0;
+    }
+
     char *outfile = 0;
     int from_stdin = 0;
     bool generate_source_map = false;
@@ -273,9 +291,11 @@ int main(int argc, char** argv) {
             break;
         case 'v':
             print_version();
+            sass_delete_options(options);
             return 0;
         case 'h':
             print_usage(argv[0]);
+            sass_delete_options(options);
             return 0;
         case '?':
             /* Unrecognized flag or missing an expected value */
@@ -283,6 +303,7 @@ int main(int argc, char** argv) {
             invalid_usage(argv[0]);
         default:
             fprintf(stderr, "Unknown error while processing arguments\n");
+            sass_delete_options(options);
             return 2;
         }
     }
@@ -293,7 +314,8 @@ int main(int argc, char** argv) {
     }
 
     int result;
-    if(optind < argc && strcmp(argv[optind], "-") != 0 && !from_stdin) {
+    const char* dash = "-";
+    if(optind < argc && strcmp(argv[optind], dash) != 0 && !from_stdin) {
         if (optind + 1 < argc) {
             outfile = argv[optind + 1];
         }
@@ -312,5 +334,7 @@ int main(int argc, char** argv) {
         result = compile_stdin(options, outfile);
     }
 
+    sass_delete_options(options);
+
     return result;
 }
